﻿//
// Copyright (c) 2015, MindFusion LLC - Bulgaria.
//

using System;
using System.Data;
using System.Globalization;
using System.Windows;
using System.Windows.Data;
using System.Windows.Media;

using MindFusion.Scheduling.Wpf;


namespace MindFusion.Scheduling.Wpf.Samples.CS.CustomMonthCalendar
{
	public class CustomCellPresenter : CellPresenter
	{
		static CustomCellPresenter()
		{
			DefaultStyleKeyProperty.OverrideMetadata(typeof(CustomCellPresenter),
				new FrameworkPropertyMetadata(typeof(CustomCellPresenter)));
			IsSelectedProperty.OverrideMetadata(typeof(CustomCellPresenter),
				new PropertyMetadata(OnIsSelectedChanged));
		}

		public CustomCellPresenter(MindFusion.Scheduling.Wpf.Calendar calendar, DataSet cellInfo)
			: base(calendar)
		{
			this.cellInfo = cellInfo;
		}

		protected override void OnStartTimeChanged(DateTime oldTime, DateTime newTime)
		{
			base.OnStartTimeChanged(oldTime, newTime);

			CellInfo = null;
			foreach (DataRow row in cellInfo.Tables[0].Rows)
			{
				DateTime date;
				if (!DateTime.TryParseExact(row["date"].ToString(), "dd/MM/yyyy", CultureInfo.InvariantCulture, System.Globalization.DateTimeStyles.None, out date))
					continue;

				if (newTime.Date != date)
					continue;

				int n, refill, change, extend;
				if (!int.TryParse(row["New"].ToString(), out n))
					continue;
				if (!int.TryParse(row["Refill"].ToString(), out refill))
					continue;
				if (!int.TryParse(row["Change"].ToString(), out change))
					continue;
				if (!int.TryParse(row["Extend"].ToString(), out extend))
					continue;

				CellInfo = new CellInfo() { New = n, Refill = refill, Change = change, Extend = extend, Total = n + refill + change + extend };
			}

			DateTime current = Calendar.Date;
			isCurrentMonth = newTime.Month == current.Month && newTime.Year == current.Year;

			IsInfoVisible = isCurrentMonth && CellInfo != null;
			UpdateBackground();
		}

		private static void OnIsSelectedChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
		{
			((CustomCellPresenter)d).UpdateBackground();
		}

		private void UpdateBackground()
		{
			if (!isCurrentMonth && !IsSelected)
			{
				Background2 = new SolidColorBrush(Color.FromArgb(255, 165, 191, 225));
			}
			else
			{
				ClearValue(Background2Property);
				SetBinding(Background2Property, new Binding("Background") { Source = this });
			}
		}

		private bool isCurrentMonth;


		public CellInfo CellInfo
		{
			get { return (CellInfo)GetValue(CellInfoProperty); }
			set { SetValue(CellInfoProperty, value); }
		}

		public static readonly DependencyProperty CellInfoProperty = DependencyProperty.Register(
			"CellInfo", typeof(CellInfo), typeof(CustomCellPresenter), new PropertyMetadata(null));

		public bool IsInfoVisible
		{
			get { return (bool)GetValue(IsInfoVisibleProperty); }
			set { SetValue(IsInfoVisibleProperty, value); }
		}

		public static readonly DependencyProperty IsInfoVisibleProperty =
			DependencyProperty.Register("IsInfoVisible", typeof(bool), typeof(CustomCellPresenter), new PropertyMetadata(true));

		public Brush Background2
		{
			get { return (Brush)GetValue(Background2Property); }
			set { SetValue(Background2Property, value); }
		}

		public static readonly DependencyProperty Background2Property =
			DependencyProperty.Register("Background2", typeof(Brush), typeof(CustomCellPresenter), new PropertyMetadata(null));


		private DataSet cellInfo;
	}

	public class CellInfo
	{
		public int Total
		{
			get;
			set;
		}

		public int New
		{
			get;
			set;
		}

		public int Refill
		{
			get;
			set;
		}

		public int Change
		{
			get;
			set;
		}

		public int Extend
		{
			get;
			set;
		}
	}

	public class BooleanToVisibilityConverter : IValueConverter
	{
		public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
		{
			if (value is bool)
			{
				bool not = false;
				if (parameter != null)
				{
					if (!bool.TryParse(parameter.ToString(), out not))
						not = false;
				}

				return (not ^ (bool)value) ? Visibility.Visible : Visibility.Collapsed;
			}

			return value;
		}

		public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
		{
			throw new System.NotImplementedException();
		}
	}
}
