﻿//
// Copyright (c) 2015, MindFusion LLC - Bulgaria.
//

using System;
using System.Windows;
using System.Windows.Media;
using System.Windows.Input;
using System.Collections.Generic;
using System.Xml.Linq;
using System.IO;
using System.Globalization;
using System.Data;
using System.Diagnostics;
using MindFusion.Scheduling.Wpf;


namespace MindFusion.Scheduling.Wpf.Samples.CS.CustomMonthCalendar
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();

			CurrentDate = DateTime.Today;

			navigationControl.Header = DateTime.Today.ToString("MMMM, yyyy");

			var selectedHeaderBrush = new LinearGradientBrush(
				new GradientStopCollection(
					new GradientStop[]
					{
						new GradientStop(Color.FromArgb(255, 168, 186, 206), 0),
						new GradientStop(Color.FromArgb(255, 154, 176, 201), 0.45),
						new GradientStop(Color.FromArgb(255, 134, 162, 195), 0.55),
						new GradientStop(Color.FromArgb(255, 148, 172, 199), 1),
					}), 90);

			var headerBrush = new LinearGradientBrush(
				new GradientStopCollection(
					new GradientStop[]
					{
						new GradientStop(Color.FromArgb(255, 228, 236, 246), 0),
						new GradientStop(Color.FromArgb(255, 214, 226, 241), 0.45),
						new GradientStop(Color.FromArgb(255, 194, 212, 235), 0.55),
						new GradientStop(Color.FromArgb(255, 208, 222, 239), 1),
					}), 90);
			var headerBrushV = new LinearGradientBrush(
				new GradientStopCollection(
					new GradientStop[]
					{
						new GradientStop(Color.FromArgb(255, 228, 236, 246), 0),
						new GradientStop(Color.FromArgb(255, 214, 226, 241), 0.45),
						new GradientStop(Color.FromArgb(255, 194, 212, 235), 0.55),
						new GradientStop(Color.FromArgb(255, 208, 222, 239), 1),
					}), 0);
			var navControlHeaderBrush = new LinearGradientBrush(
				new GradientStopCollection(
					new GradientStop[]{
						new GradientStop(Color.FromRgb(144, 179, 225), 0),
						new GradientStop(Color.FromRgb(78,113,155),1)
					}
			),90);


			SolidColorBrush background = (SolidColorBrush)calendar.WeekRangeSettings.CellSettings.CalendarStyle.Background;
			Color bgcolor = background.Color;
			bgcolor.R -= (byte)60;
			bgcolor.G -= (byte)40;
			bgcolor.B -= (byte)20;

			littleCalendars.VisibleDateChanged += (s, e) =>
				{
					 
					calendar.BeginInit();
					calendar.Date = new DateTime(littleCalendars.Date.Year, littleCalendars.Date.Month, 1);
					calendar.EndDate = calendar.Date.AddMonths(2);
					calendar.EndInit();
					navigationControl.Header = calendar.Date.ToString("MMMM, yyyy");
				};
			
			littleCalendars.MonthRangeSettings.NumberOfMonths = 3;
			littleCalendars.MonthRangeSettings.MonthsPerRow = 1;
			littleCalendars.MonthRangeSettings.MonthSpacing = new Thickness(0.5);
			littleCalendars.MonthRangeSettings.HeaderStyle.Visibility = Visibility.Hidden;
			littleCalendars.MonthRangeSettings.HeaderStyle.Background = navControlHeaderBrush;
			CalendarStyle style = new CalendarStyle();
			style.Background = headerBrush;
			style.FontSize = 16;
			CellSettings cellStyle = new CellSettings();
			cellStyle.HeaderStyle.Background = new SolidColorBrush(Colors.White);
			cellStyle.HeaderStyle.Margin = new Thickness(0.1);
			cellStyle.CalendarStyle.FontSize = 20;

			littleCalendars.MonthSettings.DaySettings = cellStyle;
			littleCalendars.MonthRangeSettings.VisibleRows = 3;
			littleCalendars.MonthSettings.SelectedElementsHeaderStyle.Background = new SolidColorBrush(bgcolor) ;
			littleCalendars.MonthSettings.DaySettings.HeaderStyle.FontSize = 11;
			littleCalendars.MonthSettings.DaySettings.HeaderStyle.Margin = new Thickness(0.6);
			littleCalendars.MonthSettings.HeaderStyle = style;
			littleCalendars.MonthSettings.CalendarStyle = style;
			littleCalendars.MonthSettings.DaySettings.HeaderSize = 0;
			littleCalendars.EndDate = littleCalendars.Date + new TimeSpan(60, 0, 0, 0);
			littleCalendars.MonthSettings.SelectedElementsHeaderStyle.Foreground = Brushes.Black;

			calendar.Date = new DateTime(DateTime.Now.Year, DateTime.Now.Month, 1);
			//change settings when is selected
			calendar.WeekRangeSettings.SelectedElementsStyle.Background = new SolidColorBrush(bgcolor);
			calendar.WeekRangeSettings.SelectedElementsStyle.BorderBrush = new SolidColorBrush(Color.FromRgb(38, 82, 125));
			calendar.WeekRangeSettings.SelectedElementsHeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.WeekRangeSettings.SelectedElementsHeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.WeekRangeSettings.SelectedElementsHeaderStyle.FontWeight = FontWeights.Bold;
			calendar.WeekRangeSettings.SelectedElementsHeaderStyle.Background = selectedHeaderBrush;
			calendar.WeekRangeSettings.SelectedElementsHeaderStyle.ContentMargin = new Thickness(2);

			calendar.WeekRangeSettings.GroupWeekends = false;

			calendar.MonthSettings.HeaderStyle.Foreground = new SolidColorBrush(Colors.Red);
			calendar.MonthSettings.HeaderStyles = MindFusion.Scheduling.Wpf.MonthHeaderStyles.None;
			calendar.MonthSettings.WeekHeaderStyle = MindFusion.Scheduling.Wpf.MonthWeekHeaderStyle.Left;
			calendar.WeekRangeSettings.TimePeriodHeaderHeight = 0;
			calendar.WeekRangeSettings.CellSettings.CalendarStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.WeekRangeSettings.CellSettings.CalendarStyle.BorderThickness = new Thickness(1);
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.Background = headerBrush;
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.FontWeight = FontWeights.Bold;
			
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.ContentMargin = new Thickness(2);
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.WeekRangeSettings.CellSettings.HeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.WeekRangeSettings.CellSettings.FirstDayOfMonthFormat = "MMM d";
			calendar.WeekRangeSettings.SelectedElementsStyle.HorizontalAlignment = HorizontalAlignment.Right;

			calendar.MonthSettings.DaySettings.CalendarStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.MonthSettings.DaySettings.CalendarStyle.BorderThickness = new Thickness(1);
			calendar.MonthSettings.DaySettings.HeaderStyle.Background = headerBrush;
			calendar.MonthSettings.DaySettings.HeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.MonthSettings.DaySettings.HeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.MonthSettings.DaySettings.HeaderStyle.FontWeight = FontWeights.Bold;
			calendar.MonthSettings.DaySettings.HeaderStyle.ContentMargin = new Thickness(2);
			calendar.MonthSettings.DaySettings.HeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.MonthSettings.DaySettings.HeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.MonthSettings.DaySettings.FirstDayOfMonthFormat = "MMM d";

			calendar.MonthSettings.PaddingDaysStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.MonthSettings.PaddingDaysStyle.BorderThickness = new Thickness(1);
			calendar.MonthSettings.PaddingDaysStyle.Background = new SolidColorBrush(Color.FromArgb(255, 165, 191, 225));
			calendar.MonthSettings.PaddingDaysHeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 141, 174, 217));
			calendar.MonthSettings.PaddingDaysHeaderStyle.BorderThickness = new Thickness(0, 0, 0, 1);
			calendar.MonthSettings.PaddingDaysHeaderStyle.Background = headerBrush;
			calendar.MonthSettings.PaddingDaysHeaderStyle.FontWeight = FontWeights.Bold;
			calendar.MonthSettings.PaddingDaysHeaderStyle.ContentMargin = new Thickness(2);
			calendar.MonthSettings.PaddingDaysHeaderStyle.HorizontalAlignment = System.Windows.HorizontalAlignment.Stretch;
			calendar.MonthSettings.PaddingDaysHeaderStyle.TextAlignment = TextAlignment.Left;
			calendar.MonthSettings.PaddingDaysHeaderStyle.Foreground = Brushes.Black;

			calendar.MonthSettings.SubHeaderStyle.Background = new SolidColorBrush(Color.FromArgb(255, 227, 239, 255));

			calendar.WeekRangeSettings.WeekHeaderPosition = MindFusion.Scheduling.Wpf.MonthWeekHeaderStyle.Left;
			calendar.WeekRangeSettings.RotateWeekHeaderTexts = true;
			calendar.WeekRangeSettings.WeekHeaderStyle.Background = headerBrushV;
			calendar.WeekRangeSettings.WeekHeaderStyle.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 74, 126, 187));
			calendar.WeekRangeSettings.WeekHeaderStyle.BorderThickness = new Thickness(1);
			calendar.WeekRangeSettings.WeekHeaderStyle.Foreground = Brushes.Black;
			calendar.WeekRangeSettings.WeekHeaderStyle.FontSize = 10;
			calendar.WeekRangeSettings.WeekHeaderStyle.Margin = new Thickness(6, 18, 0, 0);
			calendar.WeekRangeSettings.WeekNumbersHeaderWidth = 24;
			calendar.WeekRangeSettings.SubHeaderStyle.Foreground = new SolidColorBrush(Color.FromArgb(255, 101, 147, 207));
			calendar.WeekRangeSettings.SubHeaderStyle.Background = new SolidColorBrush(Color.FromArgb(255, 227, 239, 255));
			calendar.QueryHeaderText += (s, e) =>
				{
					e.Text = string.Format("{0:M/dd} - {1:dd}", e.Date, e.Date.AddDays(6));
				};

			calendar.CellPresenterCreating += calendar_CellPresenterCreating;

			r = new Random(DateTime.Now.Millisecond);

			// Load cell info
			string raw = @"<?xml version=""1.0"" encoding=""utf-8"" ?>
<info>
<data date=""24/04/2014"" New=""12"" Refill=""238"" Change=""230"" Extend=""240"" />
<data date=""25/04/2014"" New=""11"" Refill=""233"" Change=""240"" Extend=""140"" />
<data date=""26/04/2014"" New=""15"" Refill=""248"" Change=""220"" Extend=""160"" />
<data date=""27/04/2014"" New=""32"" Refill=""241"" Change=""210"" Extend=""180"" />
<data date=""28/04/2014"" New=""32"" Refill=""231"" Change=""130"" Extend=""320"" />
<data date=""29/04/2014"" New=""34"" Refill=""221"" Change=""430"" Extend=""325"" />
<data date=""30/04/2014"" New=""45"" Refill=""123"" Change=""230"" Extend=""114"" />
<data date=""31/04/2014"" New=""54"" Refill=""234"" Change=""130"" Extend=""118"" />
<data date=""01/05/2014"" New=""65"" Refill=""234"" Change=""235"" Extend=""112"" />
<data date=""02/05/2014"" New=""56"" Refill=""342"" Change=""236"" Extend=""120"" />
<data date=""03/05/2014"" New=""32"" Refill=""345"" Change=""248"" Extend=""310"" />
<data date=""04/05/2014"" New=""11"" Refill=""365"" Change=""258"" Extend=""311"" />
<data date=""05/05/2014"" New=""10"" Refill=""456"" Change=""230"" Extend=""121"" />
</info>";

			StringReader reader = new StringReader(raw);

			cellInfo = new DataSet();
			cellInfo.ReadXml(reader);
		}

		private DataSet cellInfo;

		private void CanBrowseBack(object sender, CanExecuteRoutedEventArgs e)
		{
			e.CanExecute = true;
		}

		private void OnBrowseBack(object sender, ExecutedRoutedEventArgs e)
		{
			calendar.Date = calendar.Date.AddMonths(-1);
			calendar.EndDate = calendar.Date.AddMonths(2);
			littleCalendars.Date = calendar.Date.AddMonths(-1);
			littleCalendars.EndDate = calendar.Date.AddMonths(2);
			navigationControl.Header = calendar.Date.ToString("MMMM, yyyy");
		}

		private void CanBrowseForward(object sender, CanExecuteRoutedEventArgs e)
		{
			e.CanExecute = true;
		}

		private void OnBrowseForward(object sender, ExecutedRoutedEventArgs e)
		{
			calendar.Date = calendar.Date.AddMonths(1);
			calendar.EndDate = calendar.Date.AddMonths(2);
			littleCalendars.Date = calendar.Date.AddMonths(1);
			littleCalendars.EndDate = calendar.Date.AddMonths(2);
			navigationControl.Header = calendar.Date.ToString("MMMM, yyyy");
		}

		void calendar_CellPresenterCreating(object sender, MindFusion.Scheduling.CellPresenterCreatingEventArgs e)
		{
			var presenter = new CustomCellPresenter(calendar, cellInfo);
			e.CellPresenter = presenter;
		}

		public DateTime CurrentDate
		{
			get { return (DateTime)GetValue(CurrentDateProperty); }
			set { SetValue(CurrentDateProperty, value); }
		}

		public static readonly DependencyProperty CurrentDateProperty =
			DependencyProperty.Register("CurrentDate", typeof(DateTime), typeof(MainWindow));

		private Random r;
	}
}
